@@ -1,5 +1,5 @@
 library(testthat)
 library(survParamSim)
 
-options(lifecycle_verbosity = "error")
+# options(lifecycle_verbosity = "error")
 test_check("survParamSim")
